@@ -486,8 +486,10 @@ def compute_amanuensis_data(csv_rows, low_percentage=0.04, min_days=25,
       latest_date = latest_month
     elif compute_percentage(earliest_date, latest_month, hours) >= low_percentage:
       latest_date = latest_month
+    elif compute_percentage(earliest_date, latest_date, hours) >= low_percentage:
+      pass
     else:
-      continue
+      continue # skip to next TA
 
     if latest_date - earliest_date < datetime.timedelta(days=min_days):
       continue
